@@ -90,13 +90,16 @@ class _ComicFileChooserDialog(gtk.Dialog):
             ('application/x-tar', 'application/x-gzip',
             'application/x-bzip2', 'application/x-cbt'))
         
-        if self.__class__._last_activated_file is not None and os.path.isfile(
-            self.__class__._last_activated_file):
+        try:
+            if (self.__class__._last_activated_file is not None
+                    and os.path.isfile(self.__class__._last_activated_file)):
                 self.filechooser.set_filename(
                     self.__class__._last_activated_file)
-        elif os.path.isdir(prefs['path of last browsed in filechooser']):
-            self.filechooser.set_current_folder(
-                prefs['path of last browsed in filechooser'])
+            elif os.path.isdir(prefs['path of last browsed in filechooser']):
+                self.filechooser.set_current_folder(
+                    prefs['path of last browsed in filechooser'])
+        except Exception: # E.g. broken prefs values.
+            pass
         self.show_all()
 
     def add_filter(self, name, mimes):
@@ -188,16 +191,25 @@ class _MainFileChooserDialog(_ComicFileChooserDialog):
 
         filters = self.filechooser.list_filters()
         try:
+            # When setting this to the first filter ("All files"), this
+            # fails on some GTK+ versions and sets the filter to "blank".
+            # The effect is the same though (i.e. display all files), and
+            # there is no solution that I know of, so we'll have to live
+            # with it. It only happens the second time a dialog is created
+            # though, which is very strange.
             self.filechooser.set_filter(filters[
                 prefs['last filter in main filechooser']])
         except:
-            pass
+            self.filechooser.set_filter(filters[0])
 
     def files_chosen(self, paths):
         if paths:
-            current_filter_index = self.filechooser.list_filters().index(
-                self.filechooser.get_filter())
-            prefs['last filter in main filechooser'] = current_filter_index
+            try: # For some reason this fails sometimes (GTK+ bug?)
+                filter_index = self.filechooser.list_filters().index(
+                    self.filechooser.get_filter())
+                prefs['last filter in main filechooser'] = filter_index
+            except:
+                pass
             _close_main_filechooser_dialog()
             self._window.file_handler.open_file(paths[0])
         else:
@@ -233,10 +245,16 @@ class _LibraryFileChooserDialog(_ComicFileChooserDialog):
 
         filters = self.filechooser.list_filters()
         try:
+            # When setting this to the first filter ("All files"), this
+            # fails on some GTK+ versions and sets the filter to "blank".
+            # The effect is the same though (i.e. display all files), and
+            # there is no solution that I know of, so we'll have to live
+            # with it. It only happens the second time a dialog is created
+            # though, which is very strange.
             self.filechooser.set_filter(filters[
                 prefs['last filter in library filechooser']])
-        except:
-            pass
+        except Exception:
+            self.filechooser.set_filter(filters[1])
     
     def _set_collection_name(self, *args):
         """Set the text in the ComboBoxEntry to the name of the current
@@ -255,9 +273,12 @@ class _LibraryFileChooserDialog(_ComicFileChooserDialog):
             else:
                 prefs['auto add books into collections'] = False
                 collection_name = None
-            current_filter_index = self.filechooser.list_filters().index(
-                self.filechooser.get_filter())
-            prefs['last filter in library filechooser'] = current_filter_index
+            try: # For some reason this fails sometimes (GTK+ bug?)
+                filter_index = self.filechooser.list_filters().index(
+                    self.filechooser.get_filter())
+                prefs['last filter in library filechooser'] = filter_index
+            except Exception:
+                pass
             close_library_filechooser_dialog()
             self._library.add_books(paths, collection_name)
         else:
