@@ -44,13 +44,16 @@ prefs = {
     'hide all': False,
     'hide all in fullscreen': True,
     'stored hide all values': (True, True, True, True, True),
-    'path of last browsed': constants.HOME_DIR,
+    'path of last browsed in filechooser': constants.HOME_DIR,
+    'last filter in main filechooser': 0,
+    'last filter in library filechooser': 1,
     'show menubar': True,
     'show scrollbar': True,
     'show statusbar': True,
     'show toolbar': True,
     'show thumbnails': True,
     'rotation': 0,
+    'auto rotate from exif': True,
     'vertical flip': False,
     'horizontal flip': False,
     'keep transformation': False,
@@ -64,7 +67,7 @@ prefs = {
     'lib window width': gtk.gdk.screen_get_default().get_width() * 3 // 4
 }
 
-_config_path = os.path.join(constants.COMIX_DIR, 'preferences.pickle')
+_config_path = os.path.join(constants.CONFIG_DIR, 'preferences.pickle')
 _dialog = None
 
 
@@ -304,6 +307,16 @@ class _PreferencesDialog(gtk.Dialog):
         extensions_entry.set_tooltip_text(
             _('Treat all files found within archives, that have one of these file endings, as comments.'))
         page.add_row(label, extensions_entry)
+
+        page.new_section(_('Rotation'))
+        auto_rotate_button = gtk.CheckButton(
+            _('Automatically rotate images according to their metadata.'))
+        auto_rotate_button.set_active(prefs['auto rotate from exif'])
+        auto_rotate_button.connect('toggled', self._check_button_cb,
+            'auto rotate from exif')
+        auto_rotate_button.set_tooltip_text(
+            _('Automatically rotate images when an orientation is specified in the image metadata, such as in an Exif tag.'))
+        page.add_row(auto_rotate_button)
         notebook.append_page(page, gtk.Label(_('Display')))
         self.show_all()
 
@@ -316,7 +329,7 @@ class _PreferencesDialog(gtk.Dialog):
             else:
                 self._window.draw_image(scroll=False)
         elif preference in ('stretch', 'checkered bg for transparent images',
-          'no double page for wide images'):
+          'no double page for wide images', 'auto rotate from exif'):
             self._window.draw_image(scroll=False)
         elif (preference == 'hide all in fullscreen' and
           self._window.is_fullscreen):
